@@ -1,7 +1,6 @@
-VERSION = (3, 1, 0)
+VERSION = (5, 0, 0)
 __version__ = ".".join(map(str, VERSION))
 
-default_app_config = "admin_sso.apps.AdminSSOConfig"
 
 # Do not use Django settings at module level as recommended
 try:
@@ -16,7 +15,7 @@ else:
 
             self._wrapped = Settings(default_settings)
 
-    class Settings(object):
+    class Settings:
         def __init__(self, settings_module):
             for setting in dir(settings_module):
                 if setting == setting.upper():
